<?php
/**
 * Helpers
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Oxygen\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Helpers
 *
 * @trait WP_Grid_Builder_Oxygen\Includes\Helpers
 * @since 1.0.0
 */
trait Helpers {

	/**
	 * Get the pattern to search from shortcode tagnames
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $tagnames Holds shortcode tag names.
	 * @return string
	 */
	public function get_pattern( $tagnames ) {

		$tagnames     = preg_filter( '/$/', '(?:_\d+)?', $tagnames );
		$placeholders = preg_filter( '/^/', 'tag_', range( 1, count( $tagnames ) ) );

		return str_replace( $placeholders, $tagnames, get_shortcode_regex( $placeholders ) );

	}

	/**
	 * Get element options from shortcode attributes
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string|array $atts Holds shortcode attributes.
	 * @return array
	 */
	public function get_options( $atts ) {

		if ( ! is_array( $atts ) ) {
			$atts = shortcode_parse_atts( $atts );
		}

		if ( empty( $atts['ct_options'] ) ) {
			return [];
		}

		return json_decode( $atts['ct_options'], true );

	}
}
