<?php
/**
 * Observer
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Oxygen\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Observer
 *
 * @class WP_Grid_Builder_Oxygen\Includes\Observer
 * @since 1.0.0
 */
class Observer {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_filter( 'pre_do_shortcode_tag', [ $this, 'pre_render' ], 10, 3 );
		add_filter( 'do_shortcode_tag', [ $this, 'render' ], 10, 3 );

	}

	/**
	 * Prerender shortcode
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param false|string $return Short-circuit return value. Either false or the value to replace the shortcode with.
	 * @param string       $tag    Shortcode name.
	 * @param array|string $attr   Shortcode attributes array or empty string.
	 * @return false|string
	 */
	public function pre_render( $return, $tag, $attr ) {

		if ( defined( 'SHOW_CT_BUILDER' ) ) {
			return $return;
		}

		$this->maybe_handle( $tag, $attr );

		return $return;

	}

	/**
	 * Render shortcode
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string       $output Shortcode content.
	 * @param string       $tag    Shortcode name.
	 * @param array|string $attr   Shortcode attributes array or empty string.
	 * @return string
	 */
	public function render( $output, $tag, $attr ) {

		if ( defined( 'SHOW_CT_BUILDER' ) ) {
			return $output;
		}

		return $this->maybe_render( $output, $tag, $attr );

	}

	/**
	 * Get post IDs
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function get_the_id() {

		global $oxygen_vsb_css_files_to_load;

		if ( ! is_array( $oxygen_vsb_css_files_to_load ) ) {
			return [ 0 ];
		}

		return array_map(
			'intval',
			array_unique(
				array_values( $oxygen_vsb_css_files_to_load )
			)
		);
	}
}
