<?php
/**
 * Button controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$button_style  = $this->addControlSection( 'button_style', __( 'Button', 'wpgb-oxygen' ), '', $this );
$button_colors = $button_style->addControlSection( 'button_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$button_colors->addStyleControls(
	[
		[
			'name'     => __( 'Text Hover Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button:not([disabled]):hover, button.wpgb-button:not([disabled]):focus',
			'property' => 'color',
		],
		[
			'name'     => __( 'Text Disabled Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button[disabled]',
			'property' => 'color',
		],
		[
			'name'     => __( 'Background Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Hover Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button:not([disabled]):hover, button.wpgb-button:not([disabled]):focus',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Disabled Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button[disabled]',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Border Hover Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button:not([disabled]):hover, button.wpgb-button:not([disabled]):focus',
			'property' => 'border-color',
		],
		[
			'name'     => __( 'Border Disabled Color', 'wpgb-oxygen' ),
			'selector' => 'button.wpgb-button[disabled]',
			'property' => 'border-color',
		],
	]
);

$button_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), 'button.wpgb-button', $this );
$button_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), 'button.wpgb-button', $this );

$button_spacing = $button_style->addControlSection( 'button_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$button_spacing->addStyleControl(
	[
		'control_type' => 'radio',
		'name'         => __( 'Alignment', 'wpgb-oxygen' ),
		'slug'         => 'button_alignment',
		'value'        => [
			'flex-start' => __( 'Left', 'wpgb-oxygen' ),
			'center'     => __( 'Center', 'wpgb-oxygen' ),
			'flex-end'   => __( 'Right', 'wpgb-oxygen' ),
			'stretch'    => __( 'Stretch', 'wpgb-oxygen' ),
		],
		'property'     => '',
	]
)->setValueCSS(
	[
		'flex-start' => (
			'.wpgb-facet {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-direction: column;
				flex-direction: column;
				-ms-flex-align:flex-start;
				align-items:flex-start;
			}'
		),
		'center'     => (
			'.wpgb-facet {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-direction: column;
				flex-direction: column;
				-ms-flex-align:center;
				align-items:center;
			}'
		),
		'flex-end'   => (
			'.wpgb-facet {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-direction: column;
				flex-direction: column;
				-ms-flex-align:flex-end;
				align-items:flex-end;
			}'
		),
		'stretch'    => (
			'.wpgb-facet {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-direction: column;
				flex-direction: column;
				-ms-flex-align:stretch;
				align-items:stretch;
			}'
		),
	]
);

$button_spacing->addPreset( 'padding', 'button_padding', __( 'Padding', 'wpgb-oxygen' ), 'button.wpgb-button' )->whiteList();
$button_spacing->addPreset( 'margin', 'button_margin', __( 'Margin', 'wpgb-oxygen' ), 'button.wpgb-button' )->whiteList();
$button_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), 'button.wpgb-button', $this );
