<?php
/**
 * Geolocation controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$locate_button_style = $this->addControlSection( 'locate_button_style', __( 'Locate Me Button', 'wpgb-oxygen' ), '', $this );

$locate_button_style->addOptionControl(
	[
		'type'    => 'checkbox',
		'name'    => __( 'Hide Button', 'wpgb-oxygen' ),
		'slug'    => 'locate_button',
		'default' => 'false',
	]
)->setValueCSS(
	[
		'true' => (
			'.wpgb-facet .wpgb-locate-button {
				display: none
			}'
		),
	]
);

$locate_button_colors = $locate_button_style->addControlSection( 'locate_button_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$locate_button_colors->addStyleControls(
	[
		[
			'name'     => __( 'Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-facet .wpgb-locate-button',
			'property' => 'color',
		],
		[
			'name'     => __( 'Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-facet .wpgb-locate-button:hover, .wpgb-facet .wpgb-locate-button:focus',
			'property' => 'color',
		],
	]
);

$locate_button_spacing = $locate_button_style->addControlSection( 'locate_button_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$locate_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Size', 'wpgb-oxygen' ),
		'slug'         => 'locate_button_size',
		'property'     => '--wpgb-locate-button-scale',
		'selector'     => '.wpgb-facet .wpgb-locate-button { transform: scale(calc(var(--wpgb-locate-button-scale)/20)) }',
	]
)->setRange( 10, 50, 1 );

$locate_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Horizontal Offset', 'wpgb-oxygen' ),
		'slug'         => 'locate_button_horizontal_offset',
		'property'     => 'right',
		'selector'     => '.wpgb-facet .wpgb-locate-button',
	]
)->setUnits( 'px', 'px' )->setRange( -50, 50, 1 );

$radius_control_style = $this->addControlSection( 'radius_control_style', __( 'Radius Control', 'wpgb-oxygen' ), '', $this );

$radius_control_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-facet .wpgb-geo-radius', $this );
$radius_control_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-facet .wpgb-geo-radius', $this );

$radius_control_spacing = $radius_control_style->addControlSection( 'radius_control_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$radius_control_spacing->addStyleControl(
	[
		'control_type' => 'radio',
		'name'         => __( 'Alignment', 'wpgb-oxygen' ),
		'slug'         => 'radius_control_alignment',
		'value'        => [
			'flex-start' => __( 'Left', 'wpgb-oxygen' ),
			'center'     => __( 'Center', 'wpgb-oxygen' ),
			'flex-end'   => __( 'Right', 'wpgb-oxygen' ),
		],
		'property'     => 'justify-content',
		'selector'     => '.wpgb-facet .wpgb-geo-radius',
	]
);

$radius_control_spacing->addPreset( 'padding', 'radius_control_padding', __( 'Padding', 'wpgb-oxygen' ), '.wpgb-facet .wpgb-geo-radius' )->whiteList();
$radius_control_spacing->addPreset( 'margin', 'radius_control_margin', __( 'Margin', 'wpgb-oxygen' ), '.wpgb-facet .wpgb-geo-radius' )->whiteList();
$radius_control_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), '.wpgb-facet .wpgb-geo-radius, .wpgb-facet .wpgb-geo-radius input', $this );
