<?php
/**
 * Pagination controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$pagination_style  = $this->addControlSection( 'pagination_style', __( 'Pagination', 'wpgb-oxygen' ), '', $this );
$pagination_colors = $pagination_style->addControlSection( 'pagination_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$pagination_colors->addStyleControls(
	[
		[
			'name'     => __( 'Text Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a:hover',
			'property' => 'color',
		],
		[
			'name'     => __( 'Text Current Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a[aria-current="true"]',
			'property' => 'color',
		],
		[
			'name'     => __( 'Dots Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > span',
			'property' => 'color',
		],
		[
			'name'     => __( 'Background Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a:hover',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Current Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a[aria-current="true"]',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Dots Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > span',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Border Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a:hover',
			'property' => 'border-color',
		],
		[
			'name'     => __( 'Border Current Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > a[aria-current="true"]',
			'property' => 'border-color',
		],
		[
			'name'     => __( 'Border Dots Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-page > span',
			'property' => 'border-color',
		],
	]
);

$pagination_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-page > a, .wpgb-page > span', $this );
$pagination_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-page > a', $this );

$pagination_spacing = $pagination_style->addControlSection( 'pagination_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$pagination_spacing->addStyleControl(
	[
		'control_type' => 'radio',
		'name'         => __( 'Alignment', 'wpgb-oxygen' ),
		'slug'         => 'pagination_alignment',
		'value'        => [
			'flex-start' => __( 'Left', 'wpgb-oxygen' ),
			'center'     => __( 'Center', 'wpgb-oxygen' ),
			'flex-end'   => __( 'Right', 'wpgb-oxygen' ),
		],
		'property'     => '',
	]
)->setValueCSS(
	[
		'flex-start' => (
			'.wpgb-pagination {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-wrap: wrap;
				flex-wrap: wrap;
				justify-content: flex-start;
			}'
		),
		'center'     => (
			'.wpgb-pagination {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-wrap: wrap;
				flex-wrap: wrap;
				justify-content: center;
			}'
		),
		'flex-end'   => (
			'.wpgb-pagination {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-wrap: wrap;
				flex-wrap: wrap;
				justify-content: flex-end;
			}'
		),
	]
);

$pagination_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Horizontal Spacing', 'wpgb-oxygen' ),
		'slug'         => 'pagination_horizontal_spacing',
		'property'     => '--wpgb-pagination-horizontal-spacing',
		'selector'     => (
			'.wpgb-pagination {
				margin: 0 calc(var(--wpgb-pagination-horizontal-spacing) / -2);
			}
			.wpgb-page {
				height: auto;
				min-width: auto;
				margin: 0 calc(var(--wpgb-pagination-horizontal-spacing) / 2);
			}'
		),
	]
)->setUnits( 'px', 'px' )->setRange( 0, 100, 1 );

$pagination_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Vertical Spacing', 'wpgb-oxygen' ),
		'slug'         => 'pagination_vertical_spacing',
		'property'     => '--wpgb-pagination-vertical-spacing',
		'selector'     => (
			'.wpgb-pagination {
				display: -ms-flexbox;
				display: flex;
				-ms-flex-wrap: wrap;
				flex-wrap: wrap;
				margin-bottom: calc(var(--wpgb-pagination-vertical-spacing) * -1);
			}
			.wpgb-page {
				height: auto;
				min-width: auto;
				margin-top: 0;
				margin-bottom: var(--wpgb-pagination-vertical-spacing);
			}'
		),
	]
)->setUnits( 'px', 'px' )->setRange( 0, 100, 1 );

$pagination_spacing->addPreset( 'padding', 'pagination_padding', __( 'Padding', 'wpgb-oxygen' ), '.wpgb-page > a, .wpgb-page > span' )->whiteList();
$pagination_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), '.wpgb-page > a, .wpgb-page > span', $this );
