<?php
/**
 * Range controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$range_track_style  = $this->addControlSection( 'range_track_style', __( 'Range Track', 'wpgb-oxygen' ), '', $this );
$range_track_colors = $range_track_style->addControlSection( 'range_track_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$range_track_colors->addStyleControl(
	[
		'control_type' => 'colorpicker',
		'name'         => __( 'Color', 'wpgb-oxygen' ),
		'slug'         => 'range_track_color',
		'selector'     => '.wpgb-range-slider',
		'property'     => 'background-color',
	]
);

$range_track_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-range-slider', $this );
$range_track_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-range-slider', $this );

$range_track_spacing = $range_track_style->addControlSection( 'range_track_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$range_track_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Height', 'wpgb-oxygen' ),
		'slug'         => 'range_track_height',
		'selector'     => '.wpgb-range-slider',
		'property'     => 'height',
	]
)->setUnits( 'px', 'px' )->setRange( 1, 50, 1 );

$range_progress_style  = $this->addControlSection( 'range_progress_style', __( 'Range Progress', 'wpgb-oxygen' ), '', $this );
$range_progress_colors = $range_progress_style->addControlSection( 'range_progress_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$range_progress_colors->addStyleControl(
	[
		'control_type' => 'colorpicker',
		'name'         => __( 'Color', 'wpgb-oxygen' ),
		'slug'         => 'range_progress_color',
		'selector'     => '.wpgb-range-slider .wpgb-range-progress',
		'property'     => 'background-color',
	]
);

$range_progress_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-range-slider .wpgb-range-progress', $this );
$range_progress_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-range-slider .wpgb-range-progress', $this );

$range_progress_spacing = $range_progress_style->addControlSection( 'range_progress_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$range_progress_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Height', 'wpgb-oxygen' ),
		'slug'         => 'range_progress_height',
		'selector'     => (
			'.wpgb-range-slider .wpgb-range-progress {
				height: var(--range-progress-height);
				top: calc(50% - ( var(--range-progress-height) / 2 ) );
			}'
		),
		'property'     => '--range-progress-height',
	]
)->setUnits( 'px', 'px' )->setRange( 1, 50, 1 );

$range_thumb_style  = $this->addControlSection( 'range_thumb_style', __( 'Range Thumb', 'wpgb-oxygen' ), '', $this );
$range_thumb_colors = $range_thumb_style->addControlSection( 'range_thumb_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$range_thumb_colors->addStyleControl(
	[
		'control_type' => 'colorpicker',
		'name'         => __( 'Color', 'wpgb-oxygen' ),
		'slug'         => 'range_thumb_color',
		'selector'     => '.wpgb-range-slider .wpgb-range-thumb',
		'property'     => 'background-color',
	]
);

$range_thumb_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-range-slider .wpgb-range-thumb', $this );
$range_thumb_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-range-slider .wpgb-range-thumb', $this );

$range_thumb_spacing = $range_thumb_style->addControlSection( 'range_thumb_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$range_thumb_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Width', 'wpgb-oxygen' ),
		'slug'         => 'range_thumb_width',
		'selector'     => (
			'.wpgb-range-slider .wpgb-range-progress,
			.wpgb-range-slider .wpgb-range-thumbs {
				left: calc(var(--range-thumb-width) / 2);
				right: calc(var(--range-thumb-width) / 2);
			}
			.wpgb-range-slider .wpgb-range-thumb {
				width: var(--range-thumb-width);
			}'
		),
		'property'     => '--range-thumb-width',
	]
)->setUnits( 'px', 'px' )->setRange( 1, 50, 1 );

$range_thumb_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Height', 'wpgb-oxygen' ),
		'slug'         => 'range_thumb_height',
		'selector'     => '.wpgb-range-slider .wpgb-range-thumb',
		'property'     => 'height',
	]
)->setUnits( 'px', 'px' )->setRange( 1, 50, 1 );

$range_values_style  = $this->addControlSection( 'range_values_style', __( 'Range Values', 'wpgb-oxygen' ), '', $this );
$range_values_colors = $range_values_style->addControlSection( 'range_values_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$range_values_colors->addStyleControl(
	[
		'control_type' => 'colorpicker',
		'name'         => __( 'Background Color', 'wpgb-oxygen' ),
		'slug'         => 'range_values_color',
		'selector'     => '.wpgb-range-facet .wpgb-range-values',
		'property'     => 'background-color',
	]
);

$range_values_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-values', $this );
$range_values_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-values', $this );

$range_values_spacing = $range_values_style->addControlSection( 'range_values_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$range_values_spacing->addStyleControl(
	[
		'control_type' => 'radio',
		'name'         => __( 'Alignment', 'wpgb-oxygen' ),
		'slug'         => 'range_values_alignment',
		'value'        => [
			'left'   => __( 'Left', 'wpgb-oxygen' ),
			'center' => __( 'Center', 'wpgb-oxygen' ),
			'right'  => __( 'Right', 'wpgb-oxygen' ),
		],
		'selector'     => '.wpgb-range-facet .wpgb-range-values',
		'property'     => 'text-align',
	]
);

$range_values_spacing->addPreset( 'padding', 'range_values_padding', __( 'Padding', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-values' )->whiteList();
$range_values_spacing->addPreset( 'margin', 'range_values_margin', __( 'Margin', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-values' )->whiteList();
$range_values_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-values', $this );

$range_clear_button_style = $this->addControlSection( 'range_clear_button_style', __( 'Clear Button', 'wpgb-oxygen' ), '', $this );

$range_clear_button_style->addOptionControl(
	[
		'type' => 'checkbox',
		'name' => __( 'Hide Button', 'wpgb-oxygen' ),
		'slug' => 'range_clear_button',
	]
)->setValueCSS(
	[
		'true' => '.wpgb-range-facet .wpgb-range-clear { display: none }',
	]
);

$range_clear_button_colors = $range_clear_button_style->addControlSection( 'range_clear_button_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$range_clear_button_colors->addStyleControls(
	[
		[
			'name'     => __( 'Text Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear:not([disabled]):hover',
			'property' => 'color',
		],
		[
			'name'     => __( 'Disabled Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear[disabled]',
			'property' => 'color',
		],
		[
			'name'     => __( 'Background Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear:not([disabled]):hover',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Disabled Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear[disabled]',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Border Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear:not([disabled]):hover',
			'property' => 'border-color',
		],
		[
			'name'     => __( 'Border Disabled Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-range-facet .wpgb-range-clear[disabled]',
			'property' => 'border-color',
		],
	]
);

$range_clear_button_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-clear', $this );
$range_clear_button_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-clear', $this );

$range_clear_button_spacing = $range_clear_button_style->addControlSection( 'range_clear_button_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$range_clear_button_spacing->addPreset( 'padding', 'range_clear_button_padding', __( 'Padding', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-clear' )->whiteList();
$range_clear_button_spacing->addPreset( 'margin', 'range_clear_button_margin', __( 'Margin', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-clear' )->whiteList();

$range_clear_button_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), '.wpgb-range-facet .wpgb-range-clear', $this );
