<?php
/**
 * Select controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$select_style  = $this->addControlSection( 'select_style', __( 'Select', 'wpgb-oxygen' ), '', $this );
$select_colors = $select_style->addControlSection( 'select_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$select_colors->addStyleControls(
	[
		[
			'name'      => __( 'Text Color', 'wpgb-oxygen' ),
			'selectors' => [
				[
					'selector' => '.wpgb-select, .wpgb-select .wpgb-select-search, .wpgb-select input',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select input::placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select input::-webkit-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select input::-moz-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select input:-ms-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select input:-moz-placeholder',
					'property' => 'color',
				],
			],
			'property'  => 'color',
		],
		[
			'name'      => __( 'Text Hover Color', 'wpgb-oxygen' ),
			'selectors' => [
				[
					'selector' => '.wpgb-select:hover, .wpgb-select:hover .wpgb-select-search, .wpgb-select:hover input',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select:hover input::placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select:hover input::-webkit-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select:hover input::-moz-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select:hover input:-ms-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select:hover input:-moz-placeholder',
					'property' => 'color',
				],
			],
			'property'  => 'color',
		],
		[
			'name'      => __( 'Text Focus Color', 'wpgb-oxygen' ),
			'selectors' => [
				[
					'selector' => '.wpgb-select:hover, .wpgb-select.wpgb-select-focused .wpgb-select-search, .wpgb-select.wpgb-select-focused input',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select.wpgb-select-focused input::placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select.wpgb-select-focused input::-webkit-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select.wpgb-select-focused input::-moz-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select.wpgb-select-focused input:-ms-input-placeholder',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-select.wpgb-select-focused input:-moz-placeholder',
					'property' => 'color',
				],
			],
			'property'  => 'color',
		],
		[
			'name'     => __( 'Background Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select:hover',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Background Focus Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select:focus, .wpgb-select.wpgb-select-focused',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Border Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select:hover',
			'property' => 'border-color',
		],
		[
			'name'     => __( 'Border Focus Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select:focus, .wpgb-select.wpgb-select-focused',
			'property' => 'border-color',
		],
	]
);

$select_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), '.wpgb-select', $this );
$select_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), '.wpgb-select', $this );

$select_spacing = $select_style->addControlSection( 'select_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$select_spacing->addPreset( 'padding', 'select_padding', __( 'Padding', 'wpgb-oxygen' ), '.wpgb-select' )->whiteList();
$select_spacing->addPreset( 'margin', 'select_margin', __( 'Margin', 'wpgb-oxygen' ), '.wpgb-select' )->whiteList();

$select_style->typographySection( __( 'Typography', 'wpgb-oxygen' ), '.wpgb-select, .wpgb-select *', $this );

$select_icon_style = $this->addControlSection( 'select_icon_style', __( 'Select Icon', 'wpgb-oxygen' ), '', $this );

$select_icon_style->addOptionControl(
	[
		'type'    => 'checkbox',
		'name'    => __( 'Hide Icon', 'wpgb-oxygen' ),
		'slug'    => 'select_icon',
		'default' => 'false',
	]
)->setValueCSS(
	[
		'true' => (
			'.wpgb-facet .wpgb-select-toggle, .wpgb-facet .wpgb-select-separator {
				display: none
			}'
		),
	]
);

$select_icon_style->addOptionControl(
	[
		'type'      => 'checkbox',
		'name'      => __( 'Hide Separator', 'wpgb-oxygen' ),
		'slug'      => 'select_separator',
		'condition' => 'select_icon!=true',
	]
)->setValueCSS(
	[
		'true' => '.wpgb-facet .wpgb-select-separator { display: none }',
	]
);

$select_icon_colors = $select_icon_style->addControlSection( 'select_icon_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$select_icon_colors->addStyleControls(
	[
		[
			'name'      => __( 'Icon Color', 'wpgb-oxygen' ),
			'selectors' => [
				[
					'selector' => '.wpgb-facet .wpgb-select-toggle',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-facet .wpgb-select-toggle',
					'property' => 'fill',
				],
			],
			'property'  => 'color',
		],
		[
			'name'      => __( 'Icon Hover Color', 'wpgb-oxygen' ),
			'selectors' => [
				[
					'selector' => '.wpgb-facet select.wpgb-select:hover + .wpgb-select-controls .wpgb-select-toggle, .wpgb-facet .wpgb-select-toggle:hover',
					'property' => 'color',
				],
				[
					'selector' => '.wpgb-facet select.wpgb-select:hover + .wpgb-select-controls .wpgb-select-toggle, .wpgb-facet .wpgb-select-toggle:hover',
					'property' => 'fill',
				],
			],
			'property'  => 'color',
		],
		[
			'name'     => __( 'Separator Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-facet .wpgb-select-separator',
			'property' => 'background-color',
		],
	]
);

$select_icon_spacing = $select_icon_style->addControlSection( 'select_icon_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$select_icon_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Size', 'wpgb-oxygen' ),
		'slug'         => 'select_icon_size',
		'property'     => '--wpgb-select-icon-scale',
		'selector'     => '.wpgb-facet .wpgb-select-toggle { transform: scale(calc(var(--wpgb-select-icon-scale)/20)) }',
	]
)->setRange( 10, 50, 1 );

$select_icon_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Horizontal Offset', 'wpgb-oxygen' ),
		'slug'         => 'select_icon_horizontal_offset',
		'property'     => 'right',
		'selectors'    => [
			[
				'selector' => '.wpgb-facet .wpgb-select + .wpgb-select-controls',
				'property' => 'right',
			],
			[
				'selector' => '.wpgb-facet .wpgb-select .wpgb-select-controls',
				'property' => 'margin-right',
			],
		],
	]
)->setUnits( 'px', 'px' )->setRange( -50, 50, 1 );

$select_icon_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Separator Horizontal Offset', 'wpgb-oxygen' ),
		'slug'         => 'select_separator_horizontal_offset',
		'property'     => 'margin-right',
		'selector'     => '.wpgb-facet .wpgb-select-separator',
	]
)->setUnits( 'px', 'px' )->setRange( -50, 50, 1 );

$select_loader_style = $this->addControlSection( 'select_loader_style', __( 'Select Loader', 'wpgb-oxygen' ), '', $this );

$select_loader_style->addOptionControl(
	[
		'type' => 'custom_control',
		'name' => __( 'These settings are only applied for the asynchronous combobox (facet settings).', 'wpgb-oxygen' ),
		'slug' => 'select_info_box',
		'html' => '',
	]
);

$select_loader_style->addOptionControl(
	[
		'type' => 'checkbox',
		'name' => __( 'Hide Loader', 'wpgb-oxygen' ),
		'slug' => 'select_loader',
	]
)->setValueCSS(
	[
		'true' => '.wpgb-facet .wpgb-select-loader { display: none }',
	]
);

$select_loader_color = $select_loader_style->addControlSection( 'select_loader_color', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$select_loader_color->addStyleControl(
	[
		'name'     => __( 'Color', 'wpgb-oxygen' ),
		'slug'     => 'select_loader_color',
		'property' => 'background-color',
		'selector' => '.wpgb-facet .wpgb-select-loader span',
	]
);

$select_loader_spacing = $select_loader_style->addControlSection( 'select_loader_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$select_loader_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Loader Size', 'wpgb-oxygen' ),
		'slug'         => 'select_loader_size',
		'property'     => '--wpgb-select-loader-scale',
		'selector'     => '.wpgb-facet .wpgb-select-loader { transform: translateZ(0) scale(calc(var(--wpgb-select-loader-scale)/30)) }',
	]
)->setRange( 10, 50, 1 );

$select_loader_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Horizontal Offset', 'wpgb-oxygen' ),
		'slug'         => 'select_loader_horizontal_offset',
		'property'     => 'margin-right',
		'selector'     => '.wpgb-facet .wpgb-select-loader',
	]
)->setUnits( 'px', 'px' )->setRange( -50, 50, 1 );

$selected_values_style = $this->addControlSection( 'selected_values_style', __( 'Selected Values', 'wpgb-oxygen' ), '', $this );

$selected_values_style->addOptionControl(
	[
		'type' => 'custom_control',
		'name' => __( 'These settings are only applied for the combobox (facet settings).', 'wpgb-oxygen' ),
		'slug' => 'selected_values_info_box',
		'html' => '',
	]
);

$selected_values_style->addStyleControls(
	[
		[
			'name'     => __( 'Label Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value',
			'property' => 'color',
		],
		[
			'name'     => __( 'Label Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value:hover',
			'property' => 'color',
		],
		[
			'name'     => __( 'Label Background Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Label Background Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value:hover',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Icon Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value .wpgb-select-remove',
			'property' => 'color',
		],
		[
			'name'     => __( 'Icon Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value .wpgb-select-remove:hover',
			'property' => 'color',
		],
		[
			'name'     => __( 'Icon Background Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value .wpgb-select-remove',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Icon Background Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-select-value .wpgb-select-remove:hover',
			'property' => 'background-color',
		],
	]
);

$select_clear_button_style = $this->addControlSection( 'select_clear_button_style', __( 'Clear Button', 'wpgb-oxygen' ), '', $this );

$select_clear_button_style->addOptionControl(
	[
		'type' => 'custom_control',
		'name' => __( 'These settings are only applied for the combobox (facet settings).', 'wpgb-oxygen' ),
		'slug' => 'selected_values_info_box',
		'html' => '',
	]
);

$select_clear_button_style->addOptionControl(
	[
		'type' => 'checkbox',
		'name' => __( 'Hide Button', 'wpgb-oxygen' ),
		'slug' => 'select_clear_button',
	]
)->setValueCSS(
	[
		'true' => '.wpgb-facet .wpgb-select-clear { display: none }',
	]
);

$select_clear_button_colors = $select_clear_button_style->addControlSection( 'select_clear_button_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$select_clear_button_colors->addStyleControls(
	[
		[
			'name'     => __( 'Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-facet .wpgb-select-clear',
			'property' => 'color',
		],
		[
			'name'     => __( 'Hover Color', 'wpgb-oxygen' ),
			'selector' => '.wpgb-facet .wpgb-select-clear:hover, .wpgb-facet .wpgb-select-clear:focus',
			'property' => 'color',
		],
	]
);

$select_clear_button_spacing = $select_clear_button_style->addControlSection( 'select_clear_button_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$select_clear_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Size', 'wpgb-oxygen' ),
		'slug'         => 'select_clear_button_size',
		'property'     => '--wpgb-select-clear-scale',
		'selector'     => '.wpgb-facet .wpgb-select-clear { transform: scale(calc(var(--wpgb-select-clear-scale)/20)) }',
	]
)->setRange( 10, 50, 1 );

$select_clear_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Horizontal Offset', 'wpgb-oxygen' ),
		'slug'         => 'select_clear_button_horizontal_offset',
		'property'     => 'margin-right',
		'selector'     => '.wpgb-facet .wpgb-select-clear',
	]
)->setUnits( 'px', 'px' )->setRange( -50, 50, 1 );
