<?php
/**
 * Treeview button controls
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$treeview_button_style  = $this->addControlSection( 'treeview_button_style', __( 'Treeview Buttons', 'wpgb-oxygen' ), '', $this );
$treeview_button_colors = $treeview_button_style->addControlSection( 'treeview_button_colors', __( 'Colors', 'wpgb-oxygen' ), '', $this );

$treeview_button_colors->addStyleControls(
	[
		[
			'control_type' => 'colorpicker',
			'name'         => __( 'Collapsed Icon Color', 'wpgb-oxygen' ),
			'property'     => '--wpgb-treeview-icon-color',
			'selector'     => (
				'ul li[aria-expanded="false"]:after {
					background-image: linear-gradient(var(--wpgb-treeview-icon-color), var(--wpgb-treeview-icon-color)), linear-gradient(var(--wpgb-treeview-icon-color), var(--wpgb-treeview-icon-color))
				}'
			),
		],
		[
			'control_type' => 'colorpicker',
			'name'         => __( 'Expanded Icon Color', 'wpgb-oxygen' ),
			'property'     => '--wpgb-treeview-icon-color-expanded',
			'selector'     => (
				'ul li[aria-expanded="true"]:after {
					background-image: linear-gradient(var(--wpgb-treeview-icon-color-expanded), var(--wpgb-treeview-icon-color-expanded)), linear-gradient(var(--wpgb-treeview-icon-color-expanded), var(--wpgb-treeview-icon-color-expanded))
				}'
			),
		],
		[
			'name'     => __( 'Collapsed Background Color', 'wpgb-oxygen' ),
			'selector' => 'ul li[aria-expanded="false"]:after',
			'property' => 'background-color',
		],
		[
			'name'     => __( 'Expanded Background Color', 'wpgb-oxygen' ),
			'selector' => 'ul li[aria-expanded="true"]:after',
			'property' => 'background-color',
		],
	]
);

$treeview_button_style->borderSection( __( 'Borders', 'wpgb-oxygen' ), 'ul li[aria-expanded]:after', $this );
$treeview_button_style->boxShadowSection( __( 'Box Shadow', 'wpgb-oxygen' ), 'ul li[aria-expanded]:after', $this );

$treeview_button_spacing = $treeview_button_style->addControlSection( 'treeview_button_spacing', __( 'Size & Spacing', 'wpgb-oxygen' ), '', $this );

$treeview_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Button Size', 'wpgb-oxygen' ),
		'slug'         => 'treeview_button_size',
		'property'     => '',
		'selectors'    => [
			[
				'selector' => 'ul li[aria-expanded]:after',
				'property' => 'height',
			],
			[
				'selector' => 'ul li[aria-expanded]:after',
				'property' => 'width',
			],
		],
	]
)->setUnits( 'px', 'px' )->setRange( 10, 50, 1 );

$treeview_button_spacing->addStyleControl(
	[
		'control_type' => 'slider-measurebox',
		'name'         => __( 'Icon Size', 'wpgb-oxygen' ),
		'slug'         => 'treeview_button_icon_size',
		'property'     => '--wpgb-treeview-icon-scale',
		'selector'     => (
			'ul li[aria-expanded="true"]:after {
				background-size: calc(var(--wpgb-treeview-icon-scale) * 0.5) calc(var(--wpgb-treeview-icon-scale) * 0.1);
			}
			ul li[aria-expanded="false"]:after {
				background-size: calc(var(--wpgb-treeview-icon-scale) * 0.1) calc(var(--wpgb-treeview-icon-scale) * 0.5), calc(var(--wpgb-treeview-icon-scale) * 0.5) calc(var(--wpgb-treeview-icon-scale) * 0.1);
			}'
		),
	]
)->setUnits( 'px', 'px' )->setRange( 10, 50, 1 );

$treeview_button_spacing->addPreset( 'margin', 'treeview_button_margin', __( 'Margin', 'wpgb-oxygen' ), 'ul li[aria-expanded]:after' )->whiteList();
