<?php
/**
 * Grid element
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Oxygen\Includes\Elements;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Facet element
 *
 * @class WP_Grid_Builder_Oxygen\Includes\Elements\Facet
 * @since 1.0.0
 */
final class Facet extends Base {

	/**
	 * Element slug
	 *
	 * @since 1.0.0
	 * @access public
	 * @var string
	 */
	public $slug = 'facet';

	/**
	 * Whether generic CSS has been generated
	 *
	 * @since 1.0.0
	 * @access public
	 * @var boolean
	 */
	public $generic_css = false;

	/**
	 * Element name
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string
	 */
	public function name() {

		return __( 'Facet', 'wpgb-oxygen' );

	}

	/**
	 * Element controls
	 *
	 * @since 1.0.0
	 * @access public
	 */
	protected function controls() {

		include WPGB_OXYGEN_PATH . 'includes/controls/facet.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/title.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/list.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/choice.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/label.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/counter.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/select.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/radio.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/checkbox.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/rating.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/input.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/button.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/range.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/color.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/selection.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/pagination.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/map.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/geolocation.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/treeview.php';
		include WPGB_OXYGEN_PATH . 'includes/controls/toggle.php';

	}

	/**
	 * Render content
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $options Holds element options.
	 */
	public function render_content( $options ) {

		if ( empty( $options['facet'] ) || empty( $options['grid'] ) ) {
			return;
		}

		wpgb_render_facet(
			[
				'id'   => $options['facet'],
				'grid' => $options['grid'],
			]
		);

	}

	/**
	 * Set custom CSS to each facet
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array  $options  Holds element settings.
	 * @param string $selector Element CSS selector.
	 * @return string
	 */
	public function customCSS( $options, $selector ) {

		$css = $this->generic_css();

		if (
			! empty( $options['oxy-wpgb-facet_type'] ) &&
			'map' === $options['oxy-wpgb-facet_type']
		) {

			$css .= (
				$selector . ' .wpgb-facet fieldset {
					position: relative;
					width: 100%;
				}' .
				$selector . ' .wpgb-facet .wpgb-map-facet {
					height: 640px;
					padding: 0 !important;
				}' .
				$selector . ' .wpgb-facet .wpgb-map-pan-to-search .wpgb-checkbox-control {
					text-align: initial;
				} '
			);

		}

		return $css;

	}

	/**
	 * Set generic CSS once
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string
	 */
	public function generic_css() {

		if ( $this->generic_css ) {
			return '';
		}

		$this->generic_css = true;

		return (
			'.oxy-wpgb-facet {' .
				'width: 100%' .
			'}
			.oxy-wpgb-facet .wpgb-facet > fieldset:last-child,
			.oxy-wpgb-facet .wpgb-facet > .wpgb-button {
				margin-bottom: 0;
			} '
		);

	}
}
