<?php
/**
 * Easy Posts
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Oxygen\Includes\Providers;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Easy Posts element
 *
 * @class WP_Grid_Builder_Oxygen\Includes\Providers\Easy_Posts
 * @since 1.0.0
 */
final class Easy_Posts extends Provider {

	/**
	 * Get element options
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function options() {

		$options = parent::options();

		if ( ! empty( $this->element['original']['wpgb_hide_pagination'] ) ) {
			$options['itemSelector'] = $this->get_selector() . ' .oxy-posts > *';
		}

		return $options;

	}

	/**
	 * Get inline script
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string
	 */
	public function script() {

		$script = parent::script();

		if ( ! empty( $this->element['original']['wpgb_hide_pagination'] ) ) {
			$script .= 'template.dataset.options=' . wp_json_encode( sanitize_html_class( $this->get_id() ) ) . ';';
		}

		return $script;

	}

	/**
	 * Remove pagination
	 *
	 * @since 1.0.0
	 *
	 * @param string $content Element content to output.
	 * @return string
	 */
	public function remove_pagination( $content ) {

		return preg_replace( '~<div([^>]*)class=["\']oxy-easy-posts-pages["\']([^>]*)>(.*?)</div>~ims', '', $content );

	}
}
