<?php
/**
 * WP Grid Builder Oxygen Add-on
 *
 * @package   WP Grid Builder - Oxygen
 * @author    Loïc Blascos
 * @link      https://www.wpgridbuilder.com
 * @copyright 2019-2022 Loïc Blascos
 *
 * @wordpress-plugin
 * Plugin Name:  WP Grid Builder - Oxygen
 * Plugin URI:   https://www.wpgridbuilder.com
 * Description:  Integrate WP Grid Builder with Oxygen plugin.
 * Version:      1.1.2
 * Author:       Loïc Blascos
 * Author URI:   https://www.wpgridbuilder.com
 * License:      GPL-3.0-or-later
 * License URI:  https://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:  wpgb-oxygen
 * Domain Path:  /languages
 */

namespace WP_Grid_Builder_Oxygen;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

define( 'WPGB_OXYGEN_VERSION', '1.1.2' );
define( 'WPGB_OXYGEN_FILE', __FILE__ );
define( 'WPGB_OXYGEN_BASE', plugin_basename( WPGB_OXYGEN_FILE ) );
define( 'WPGB_OXYGEN_PATH', plugin_dir_path( WPGB_OXYGEN_FILE ) );
define( 'WPGB_OXYGEN_URL', plugin_dir_url( WPGB_OXYGEN_FILE ) );

require_once WPGB_OXYGEN_PATH . 'includes/class-autoload.php';

/**
 * Load plugin text domain.
 *
 * @since 1.0.0
 */
function textdomain() {

	load_plugin_textdomain(
		'wpgb-oxygen',
		false,
		basename( dirname( WPGB_OXYGEN_FILE ) ) . '/languages'
	);

}
add_action( 'plugins_loaded', __NAMESPACE__ . '\textdomain' );

/**
 * Plugin compatibility notice.
 *
 * @since 1.0.0
 */
function plugin_notice() {

	$notice = __( '<strong>Gridbuilder ᵂᴾ - Oxygen</strong> add-on requires at least <code>Gridbuilder ᵂᴾ v1.5.4</code>. Please update Gridbuilder ᵂᴾ to use Oxygen add-on.', 'wpgb-oxygen' );

	echo '<div class="error">' . wp_kses_post( wpautop( $notice ) ) . '</div>';

}

/**
 * Oxygen compatibility notice.
 *
 * @since 1.0.0
 */
function oxygen_notice() {

	$notice = __( '<strong>Gridbuilder ᵂᴾ - Oxygen</strong> add-on requires at least <code>Oxygen v3.3.0</code>. Please update and activate Oxygen.', 'wpgb-oxygen' );

	echo '<div class="error">' . wp_kses_post( wpautop( $notice ) ) . '</div>';

}

/**
 * Initialize plugin
 *
 * @since 1.0.0
 */
function loaded() {

	if ( version_compare( WPGB_VERSION, '1.5.4', '<' ) ) {

		add_action( 'admin_notices', __NAMESPACE__ . '\plugin_notice' );
		return;

	}

	if ( ! defined( 'CT_VERSION' ) || version_compare( CT_VERSION, '3.3.0', '<' ) ) {

		add_action( 'admin_notices', __NAMESPACE__ . '\oxygen_notice' );
		return;

	}

	new Includes\Plugin();

}
add_action( 'wp_grid_builder/loaded', __NAMESPACE__ . '\loaded' );
