<?php
/**
 * Block
 *
 * @package   WP Grid Builder - Pods
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Pods\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Block
 *
 * @class WP_Grid_Builder_Pods\Includes\Block
 * @since 1.0.0
 */
final class Block {

	use Helpers;

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_filter( 'wp_grid_builder/block/custom_field', [ $this, 'custom_field_block' ], 10, 2 );

	}

	/**
	 * Output Pods field value
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $output Custom field output.
	 * @param string $field  Field identifier.
	 * @return string
	 */
	public function custom_field_block( $output, $field ) {

		if ( ! $this->is_pods_field( $field ) ) {
			return $output;
		}

		return $this->get_field( $field, wpgb_get_the_id() );

	}

	/**
	 * Handle paragraph field
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $value Field value.
	 * @param array  $field Holds field settings.
	 * @return string
	 */
	public function paragraph_field( $value, $field ) {

		if ( empty( $value ) ) {
			return '';
		}

		if ( 'code' === $field['type'] ) {
			$value = '<pre><code>' . esc_textarea( $value ) . '</code></pre>';
		}

		return $value;

	}

	/**
	 * Handle toggle field
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param integer $value Field value.
	 * @param array   $field Holds field settings.
	 * @return string
	 */
	public function toggle_field( $value, $field ) {

		if ( empty( $value ) ) {
			return '';
		}

		return $value;

	}

	/**
	 * Handle relationship field
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param mixed  $value Field value.
	 * @param array  $field Holds field settings.
	 * @param object $pods  Pods instance.
	 * @return string
	 */
	public function relationship_field( $value, $field, $pods ) {

		if ( empty( $value ) ) {
			return '';
		}

		if ( in_array( $field['pick_object'], [ 'nav_menu', 'post_format' ], true ) ) {

			$args = explode( ',', $value );

			if ( ! empty( $args[1] ) ) {
				$value = $args[1];
			}
		}

		return $value;

	}

	/**
	 * Handle default field
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param string $value Field value.
	 * @return string
	 */
	public function default_field( $value ) {

		return $value;

	}
}
