<?php
/**
 * Fields
 *
 * @package   WP Grid Builder - Pods
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Pods\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Fields
 *
 * @class WP_Grid_Builder_Pods\Includes\Fields
 * @since 1.0.0
 */
final class Fields {

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_filter( 'wp_grid_builder/custom_fields', [ $this, 'register_fields' ], 10, 2 );

	}

	/**
	 * Register Pods fields
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $fields Holds registered custom fields.
	 * @return array
	 */
	public function register_fields( $fields ) {

		$fields['Pods'] = $this->get_fields();

		return $fields;

	}

	/**
	 * Retrieve Pods fields
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array
	 */
	public function get_fields() {

		$fields = [];
		$pods   = pods_api()->load_pods();

		foreach ( $pods as $pod ) {
			foreach ( $pod['fields'] as $field ) {
				$fields[ 'pods/' . $field['pod'] . '/' . $field['name'] ] = 'Pods &rsaquo; ' . $pod['label'] . ' &rsaquo; ' . $field['label'];
			}
		}

		return $fields;

	}
}
