<?php
/**
 * Sort
 *
 * @package   WP Grid Builder - Pods
 * @author    Loïc Blascos
 * @copyright 2019-2022 Loïc Blascos
 */

namespace WP_Grid_Builder_Pods\Includes;

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Sort
 *
 * @class WP_Grid_Builder_Pods\Includes\Sort
 * @since 1.0.0
 */
final class Sort {

	use Helpers;

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		add_filter( 'wp_grid_builder/facet/sort_query_vars', [ $this, 'sort_query_vars' ] );

	}

	/**
	 * Change sort query variables
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $query_vars Holds query sort variables.
	 * @return array
	 */
	public function sort_query_vars( $query_vars ) {

		if ( empty( $query_vars['meta_key'] ) ) {
			return $query_vars;
		}

		if ( ! $this->is_pods_field( $query_vars['meta_key'] ) ) {
			return $query_vars;
		}

		$field_name = $this->get_pods_field_name( $query_vars['meta_key'] );

		if ( empty( $field_name ) ) {
			return $query_vars;
		}

		$query_vars['meta_key'] = $field_name;

		return $query_vars;

	}
}
